@@ -1,4 +1,4 @@
-VERSION = (0, 3, 0)
+VERSION = (0, 4, 0)
 __version__ = '.'.join(map(str, VERSION))
 
 
@@ -6,7 +6,11 @@ _none_type = 0xc0ffee
 _available_languages = None
 
 
-def get_url(key, language=None):
+class KeyDoesNotExist(Exception):
+    pass
+
+
+def get_url(key, language=None, fail_silently=False):
     global _available_languages
 
     from django.conf import settings
@@ -47,6 +51,12 @@ def get_url(key, language=None):
 
             cache.set(cache_key, _none_type if url is None else url, 120)
 
+    if url == _none_type:
+        url = None
+
+    if url is None and not fail_silently:
+        raise KeyDoesNotExist('No match found for key "%s".' % url)
+
     return None if url == _none_type else url
 
 
